Enum FDomainError
pub enum FDomainError {
Show 13 variants
TargetError(i32),
BadHandleId(BadHandleId),
NewHandleIdOutOfRange(NewHandleIdOutOfRange),
NewHandleIdReused(NewHandleIdReused),
WrongHandleType(WrongHandleType),
StreamingReadInProgress(StreamingReadInProgress),
NoReadInProgress(NoReadInProgress),
WroteToSelf(WroteToSelf),
ClosedDuringRead(ClosedDuringRead),
SignalsUnknown(SignalsUnknown),
RightsUnknown(RightsUnknown),
SocketDispositionUnknown(SocketDispositionUnknown),
SocketTypeUnknown(SocketTypeUnknown),
// some variants omitted
}Variants
TargetError(i32)
An error produced by interacting with the handle itself.
BadHandleId(BadHandleId)
An invalid handle ID was given.
NewHandleIdOutOfRange(NewHandleIdOutOfRange)
We passed a NewHandleId that contained an ID with a 1 in the most
significant bit.
NewHandleIdReused(NewHandleIdReused)
We passed a NewHandleId that collides with an already-allocated handle.
WrongHandleType(WrongHandleType)
The handle used is not of the right type for the operation requested.
StreamingReadInProgress(StreamingReadInProgress)
Occurs when we try to start streaming reading twice on the same handle, or try to directly read from a handle which we are already streaming reading from.
NoReadInProgress(NoReadInProgress)
We tried to stop streaming reading on a handle we weren’t streaming reads from to begin with.
WroteToSelf(WroteToSelf)
We tried to write a channel into itself.
ClosedDuringRead(ClosedDuringRead)
We received a request to close or transfer a handle while we were waiting to read from it.
SignalsUnknown(SignalsUnknown)
The flexible features of this protocol allowed the client to send us signals that we didn’t actually understand, and we couldn’t proceed safely without knowing what they were. The signals field should contain only the signals that weren’t understood.
RightsUnknown(RightsUnknown)
The flexible features of this protocol allowed the client to send us rights that we didn’t actually understand, and we couldn’t proceed safely without knowing what they were. The rights field should contain only the rights that weren’t understood.
SocketDispositionUnknown(SocketDispositionUnknown)
The client used a socket disposition that the FDomain did not recognize.
SocketTypeUnknown(SocketTypeUnknown)
The client used a socket type that the FDomain did not recognize.
Implementations
impl Error
impl Error
pub fn ordinal(&self) -> u64
pub fn unknown_variant_for_testing() -> Error
pub fn is_unknown(&self) -> bool